@@ -4,7 +4,7 @@ use strict;
 use warnings;
 
 
-our $VERSION     = '0.098';
+our $VERSION     = '0.099';
 $VERSION = eval $VERSION;
 
 1;
@@ -18,7 +18,7 @@ Gtk2::Ex::DbLinker - Use sql or orm objects to build a gtk2 Gui
 
 =head1 VERSION
 
-version  0.098 but see version at the end of MYMETA.yml to check that I'm correct here...
+version  0.099 but see version at the end of MYMETA.yml to check that I'm correct here...
 
 =head1 INSTALLATION
 
@@ -130,7 +130,7 @@ C<runeexample2_rdb.pl> uses Rose::Data::Object. The database is the same as exam
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
-L<http://code.google.com/p/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
 
 =head1 AUTHOR
 
