@@ -1040,7 +1040,7 @@ Revert the row to the original state in displaying the values fetch from the dat
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
-L<http://code.google.com/p/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
 
 =head1 AUTHOR
 
