@@ -87,7 +87,12 @@ sub set_row_pos{
 		#die Dumper( $self->{data}[$pos] );
 		my $r;
 		if ( $self->{usefind} ) {
+			  $self->{log}->debug("usefind is true rs count: " . $self->{rs}->count);
+			  my $sql =  $self->{rs}->as_query;
+			  $self->{log}->debug("sql  and bound values : " .  join(" * ", @$$sql) );
+			  $self->{log}->debug("searching " . join(" ", @{ $self->{data}[$pos] }  ));
 			 $r =  $self->{rs}->find(@{ $self->{data}[$pos] });
+			 $self->{log}->debug("cols: " . join(" ", $r->columns));
 		} else {
 			
 			my %h;
@@ -96,8 +101,8 @@ sub set_row_pos{
 			for my $key (@{$self->{primary_keys}}){
 				$h{"me." . $key} = $vals[$i++];	
 			}
-			$self->{log}->debug( join(" ", keys %h));
-			$self->{log}->debug( join(" ", values %h));
+			$self->{log}->debug("keys: " . join(" ", keys %h));
+			$self->{log}->debug("values: " . join(" ", values %h));
 			my $rs =  $self->{rs}->search(\%h); 
 			$r = $rs->single();
 			$self->{log}->debug("count (should be 1) : ", $rs->count);	
@@ -181,9 +186,12 @@ sub save{
 		$row = $self->{current_row};
 		# $self->{log}->debug(Dumper($row));
 		try {
-			$result = $row->update;
-			$self->{log}->debug("saving and unsetting new row");
-			$done = 1;
+			#$result = $row->update;
+			if ($row->update) {
+				$self->{new_row} = undef;
+				$self->{log}->debug("saving and unsetting new row");
+				$done = 1;
+			}
 		} catch {
 			carp ("Can't save record : $_");
 			$done = 0;
@@ -195,9 +203,9 @@ sub save{
 
 	#$row->save;
 	#don't delete new_row is inserting in the db gets wrong
-	if ($result) {
-		$self->{new_row} = undef;
-	}
+	#if ($result) {
+	#	$self->{new_row} = undef;
+	#}
 	return $done;
 }
 sub new_row {
@@ -592,7 +600,7 @@ Return an array of auto incremented primary key(s) from the underlying result_so
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
-L<http://code.google.com/p/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
 
 =head1 AUTHOR
 
