@@ -354,6 +354,7 @@ sub _display_data {
 
 sub undo{
 	my $self = shift;
+	 $self->{log}->debug("undo clicked");
 	 $self->{changed}=0;
 	 $self->{pos2del}= [];
 	 $self->_display_data( $self->{pos}  );
@@ -1187,7 +1188,7 @@ Return 1 if the data has been edited in the form and in any subform added with C
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account.  
 
 The current state of the source can be extract using Mercurial from
-L<http://code.google.com/p/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
 
 =head1 AUTHOR
 
