@@ -524,7 +524,7 @@ Return an array of autoincremented primary key(s) defined by the the 'serial' co
 Any Gk2::Ex::DbLinker questions or problems can be posted to me (rappazf) on my gmail account. 
 
 The current state of the source can be extract using Mercurial from
-L<http://code.google.com/p/gtk2-ex-dblinker/>.
+L<http://sourceforge.net/projects/gtk2-ex-dblinker/>.
 
 =head1 AUTHOR
 
